@@ -1,5 +1,8 @@
-from django.contrib.sites.models import SiteManager, Site
+from django.contrib.sites.models import SiteManager
 from threaded_multihost import sites
+import logging
+
+log = logging.getLogger('threaded_multihost')
 
 def site_get_current(self):
     """Overridden version of get_current, which is multihost aware."""
@@ -7,3 +10,4 @@ def site_get_current(self):
 
 SiteManager.get_current = site_get_current
 SiteManager.MULTIHOST = True
+log.debug('Patched Django for multihost awareness.')
